-----

Documentation: [html](https://docs-beta.ethers.io/)

-----


Application Programming Interface (API)
=======================================


Here...


* [Contracts](contract)
  * [Buckets](contract)
* [Signers](signer)
  * [Signer](signer)
  * [Wallet](signer)
  * [VoidSigner](signer)
  * [ExternallyOwnedAccount](signer)
* [Providers](providers)
  * [Provider](providers/provider)
    * [Accounts Methods](providers/provider)
    * [Blocks Methods](providers/provider)
    * [Ethereum Naming Service (ENS) Methods](providers/provider)
    * [Logs Methods](providers/provider)
    * [Network Status Methods](providers/provider)
    * [Transactions Methods](providers/provider)
    * [Event Emitter Methods](providers/provider)
    * [Inspection Methods](providers/provider)
  * [JsonRpcProvider](providers/jsonrpc-provider)
    * [JsonRpcSigner](providers/jsonrpc-provider)
    * [JsonRpcUncheckedSigner](providers/jsonrpc-provider)
  * [API Providers](providers/api-providers)
    * [EtherscanProvider](providers/api-providers)
    * [InfuraProvider](providers/api-providers)
    * [AlchemyProvider](providers/api-providers)
    * [CloudfrontProvider](providers/api-providers)
  * [Other Providers](providers/other)
    * [FallbackProvider](providers/other)
    * [IpcProvider](providers/other)
    * [UrlJsonRpcProvider](providers/other)
    * [Web3Provider](providers/other)
  * [Types](providers/types)
    * [Network](providers/types)
    * [Block](providers/types)
    * [Events and Logs](providers/types)
    * [Transactions](providers/types)
* [Utilities](utils)
  * [Addresses](utils/address)
    * [Address Formats](utils/address)
    * [Functions](utils/address)
  * [Application Binary Interface](utils/abi)
    * [Formats](utils/abi)
    * [Fragment](utils/abi)
    * [ConstructorFragment](utils/abi)
    * [EventFragment](utils/abi)
    * [FunctionFragment](utils/abi)
    * [ParamType](utils/abi)
  * [BigNumber](utils/bignumber)
    * [Types](utils/bignumber)
    * [Creating Instances](utils/bignumber)
    * [Methods](utils/bignumber)
    * [Notes](utils/bignumber)
  * [Byte Manipulation](utils/bytes)
    * [Types](utils/bytes)
    * [Inspection](utils/bytes)
    * [Converting between Arrays and Hexstrings](utils/bytes)
    * [Array Manipulation](utils/bytes)
    * [Hexstring Manipulation](utils/bytes)
    * [Signature Conversion](utils/bytes)
  * [Constants](utils/constants)
    * [Bytes](utils/constants)
    * [Strings](utils/constants)
    * [BigNumber](utils/constants)
  * [Display Logic and Input](utils/display-logic)
    * [Units](utils/display-logic)
    * [Functions](utils/display-logic)
  * [FixedNumber](utils/fixednumber)
    * [FixedFormat](utils/fixednumber)
    * [Creating Instances](utils/fixednumber)
    * [Properties](utils/fixednumber)
    * [Methods](utils/fixednumber)
  * [Hashing Algorithms](utils/hashing)
    * [Cryptographic Hashing](utils/hashing)
    * [Common Hashing Helpers](utils/hashing)
    * [Solidity Hashing Algorithms](utils/hashing)
  * [Strings](utils/strings)
    * [Bytes32String](utils/strings)
    * [UTF-8 Strings](utils/strings)
    * [UnicodeNormalizationForm](utils/strings)
    * [Custom UTF-8 Error Handling](utils/strings)
  * [Transactions](utils/transactions)
    * [Types](utils/transactions)
    * [Functions](utils/transactions)
* [Other Libraries](other)
  * [Hardware Wallets](other/hardware)
    * [LedgerSigner](other/hardware)



-----
**Content Hash:** 9efeac06691d2415dcc248d1567676602f7df029abd5f844480b12bb844588a7